@@ -89,16 +89,17 @@ sub defaults {
             undef             => '',
         },
         insert => {
-            file_encoding         => 'UTF-8',
-            history_dirs          => 4,
-            parse_mode_input_copy => 1,
-            parse_mode_input_file => 0,
-            empty_to_null_plain   => 1,
-            empty_to_null_copy    => 1,
-            empty_to_null_file    => 0,
-            data_source           => 3,
-            show_hidden_files     => 0,
-            file_filter           => '',
+            file_encoding            => 'UTF-8',
+            history_dirs             => 4,
+            parse_mode_input_copy    => 1,
+            parse_mode_input_file    => 0,
+            empty_to_null_plain      => 1,
+            empty_to_null_copy       => 1,
+            empty_to_null_file       => 0,
+            data_source_Create_table => 3,
+            data_source_Insert       => 3,
+            show_hidden_files        => 0,
+            file_filter              => '',
         },
         create => {
             autoincrement_col_name => 'Id',
